==> android-2.3.3-sources.jar: android/widget/TabWidget.java <==
package android.widget;
public class TabWidget
  extends android.widget.LinearLayout
  implements android.view.View.OnFocusChangeListener
{
public  TabWidget(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null); throw new RuntimeException("Stub!"); }
public  TabWidget(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null); throw new RuntimeException("Stub!"); }
public  TabWidget(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null); throw new RuntimeException("Stub!"); }
protected  void onSizeChanged(int w, int h, int oldw, int oldh) { throw new RuntimeException("Stub!"); }
protected  int getChildDrawingOrder(int childCount, int i) { throw new RuntimeException("Stub!"); }
public  android.view.View getChildTabViewAt(int index) { throw new RuntimeException("Stub!"); }
public  int getTabCount() { throw new RuntimeException("Stub!"); }
public  void setDividerDrawable(android.graphics.drawable.Drawable drawable) { throw new RuntimeException("Stub!"); }
public  void setDividerDrawable(int resId) { throw new RuntimeException("Stub!"); }
public  void setLeftStripDrawable(android.graphics.drawable.Drawable drawable) { throw new RuntimeException("Stub!"); }
public  void setLeftStripDrawable(int resId) { throw new RuntimeException("Stub!"); }
public  void setRightStripDrawable(android.graphics.drawable.Drawable drawable) { throw new RuntimeException("Stub!"); }
public  void setRightStripDrawable(int resId) { throw new RuntimeException("Stub!"); }
public  void setStripEnabled(boolean stripEnabled) { throw new RuntimeException("Stub!"); }
public  boolean isStripEnabled() { throw new RuntimeException("Stub!"); }
public  void childDrawableStateChanged(android.view.View child) { throw new RuntimeException("Stub!"); }
public  void dispatchDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
public  void setCurrentTab(int index) { throw new RuntimeException("Stub!"); }
public  void focusCurrentTab(int index) { throw new RuntimeException("Stub!"); }
public  void setEnabled(boolean enabled) { throw new RuntimeException("Stub!"); }
public  void addView(android.view.View child) { throw new RuntimeException("Stub!"); }
public  void onFocusChange(android.view.View v, boolean hasFocus) { throw new RuntimeException("Stub!"); }
}

==> android-4.0.1.2-sources.jar: android/widget/TabWidget.java <==
package android.widget;
public class TabWidget
  extends android.widget.LinearLayout
  implements android.view.View.OnFocusChangeListener
{
public  TabWidget(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  TabWidget(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  TabWidget(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
protected  void onSizeChanged(int w, int h, int oldw, int oldh) { throw new RuntimeException("Stub!"); }
protected  int getChildDrawingOrder(int childCount, int i) { throw new RuntimeException("Stub!"); }
public  android.view.View getChildTabViewAt(int index) { throw new RuntimeException("Stub!"); }
public  int getTabCount() { throw new RuntimeException("Stub!"); }
public  void setDividerDrawable(android.graphics.drawable.Drawable drawable) { throw new RuntimeException("Stub!"); }
public  void setDividerDrawable(int resId) { throw new RuntimeException("Stub!"); }
public  void setLeftStripDrawable(android.graphics.drawable.Drawable drawable) { throw new RuntimeException("Stub!"); }
public  void setLeftStripDrawable(int resId) { throw new RuntimeException("Stub!"); }
public  void setRightStripDrawable(android.graphics.drawable.Drawable drawable) { throw new RuntimeException("Stub!"); }
public  void setRightStripDrawable(int resId) { throw new RuntimeException("Stub!"); }
public  void setStripEnabled(boolean stripEnabled) { throw new RuntimeException("Stub!"); }
public  boolean isStripEnabled() { throw new RuntimeException("Stub!"); }
public  void childDrawableStateChanged(android.view.View child) { throw new RuntimeException("Stub!"); }
public  void dispatchDraw(android.graphics.Canvas canvas) { throw new RuntimeException("Stub!"); }
public  void setCurrentTab(int index) { throw new RuntimeException("Stub!"); }
public  boolean dispatchPopulateAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onInitializeAccessibilityEvent(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void focusCurrentTab(int index) { throw new RuntimeException("Stub!"); }
public  void setEnabled(boolean enabled) { throw new RuntimeException("Stub!"); }
public  void addView(android.view.View child) { throw new RuntimeException("Stub!"); }
public  void removeAllViews() { throw new RuntimeException("Stub!"); }
public  void sendAccessibilityEventUnchecked(android.view.accessibility.AccessibilityEvent event) { throw new RuntimeException("Stub!"); }
public  void onFocusChange(android.view.View v, boolean hasFocus) { throw new RuntimeException("Stub!"); }
}
